@@ -22,6 +22,15 @@ SUPPORTED_ACCESSOR_ATTRS = [
 
 
 UNSUPPORTED_ATTR_KEYS = ['dataType', 'values']
+ATTR_KEYS_WITH_NUMERIC_VALS = [
+    'battery',
+    'illuminance',
+    'ultravioletIndex',
+    'temperature',
+    'humidity',
+    'energy',
+    'power',
+]
 
 
 def date_to_timestamp(date_str):
@@ -61,7 +70,10 @@ class HubitatCachingClient(HubitatClient):
                     if k not in UNSUPPORTED_ATTR_KEYS:
                         self.device_cache.add_device_for_capability_and_attribute(capability, k, v, alias)
                         self.device_cache.set_last_device_attr_value(capability, alias, k, v)
-                        self.device_cache.set_last_device_attr_timestamp(capability, alias, k, v, timestamp)
+                        if k in ATTR_KEYS_WITH_NUMERIC_VALS:
+                            self.device_cache.set_last_device_attr_timestamp(capability, alias, k, None, timestamp)
+                        else:
+                            self.device_cache.set_last_device_attr_timestamp(capability, alias, k, v, timestamp)
 
     def get_devices_by_capability(self, capability):
         return self.device_cache.get_devices_by_capability(capability)
@@ -102,4 +114,7 @@ class HubitatCachingClient(HubitatClient):
                         self.device_cache.remove_device_for_capability_and_attribute(capability, k, v, alias)
 
         self.device_cache.set_last_device_attr_value(capability, alias, event.attr_key, event.attr_value)
-        self.device_cache.set_last_device_attr_timestamp(capability, alias, event.attr_key, event.attr_value, event.timestamp)
+        if event.attr_key in ATTR_KEYS_WITH_NUMERIC_VALS:
+            self.device_cache.set_last_device_attr_timestamp(capability, alias, event.attr_key, None, event.timestamp)
+        else:
+            self.device_cache.set_last_device_attr_timestamp(capability, alias, event.attr_key, event.attr_value, event.timestamp)
